save_token: Save token to file
Description
save_token saves the DNB token to file, so the user does not to enter it for each R session.
Usage
save_token(token = dnb_token(), path = paste(normalizePath("~/"),
".Renviron", sep = "/"))Arguments
token
the personal DNB token as string.
path
the path to the file where the token is stored. Default is the .Renvion file in the users home directory.
Examples
Run this code# NOT RUN {
save_token(token="YOUR_TOKEN_HERE")
# }
Run the code above in your browser using DataLab